@@ -45,7 +45,7 @@ test_that("download example data", {
 
 
 
-path_otp <- otp_dl_jar(path_data, quiet = TRUE)
+path_otp <- otp_dl_jar(path_data, quiet = TRUE, cache = FALSE)
 
 test_that("download otp", {
   expect_true(file.exists(file.path(path_otp)))
@@ -87,16 +87,16 @@ test_that("otp_plan input validation", {
   regexp = "Number of fromPlaces and toPlaces do not match"
   )
   expect_error(otp_plan(otpcon,
-                        toPlace = matrix(c(1.23, 1.23, 2.34, 2.34), ncol = 2),
-                        fromPlace = matrix(c(1.23, 1.23), ncol = 2),
-                        toID = c("A", "B", "C")
+    toPlace = matrix(c(1.23, 1.23, 2.34, 2.34), ncol = 2),
+    fromPlace = matrix(c(1.23, 1.23), ncol = 2),
+    toID = c("A", "B", "C")
   ),
   regexp = "The length of toID and toPlace are not the same"
   )
   expect_error(otp_plan(otpcon,
-                        toPlace = matrix(c(1.23, 1.23, 2.34, 2.34), ncol = 2),
-                        fromPlace = matrix(c(1.23, 1.23), ncol = 2),
-                        fromID = c("A", "B", "C")
+    toPlace = matrix(c(1.23, 1.23, 2.34, 2.34), ncol = 2),
+    fromPlace = matrix(c(1.23, 1.23), ncol = 2),
+    fromID = c("A", "B", "C")
   ),
   regexp = "The length of fromID and fromPlace are not the same"
   )
@@ -106,16 +106,16 @@ test_that("otp_plan input validation", {
     geom = sf::st_sfc(sf::st_linestring(rbind(c(0, 0), c(1, 1), c(2, 1))))
   ))
   expect_error(otp_plan(otpcon,
-                        fromPlace = ls,
-                        toPlace = matrix(c(1, 1), ncol = 2)
+    fromPlace = ls,
+    toPlace = matrix(c(1, 1), ncol = 2)
   ),
   regexp = "contains non-POINT geometry"
   )
 
   skip_on_cran()
   expect_error(otp_plan(otpcon,
-                        fromPlace = c(1.23, 1.23),
-                        toPlace = c(1.23, 1.23)
+    fromPlace = c(1.23, 1.23),
+    toPlace = c(1.23, 1.23)
   ),
   regexp = "Failed to connect to localhost port 8080"
   )
@@ -140,7 +140,6 @@ test_that("otp_plan input validation", {
   ),
   regexp = "Failed to connect to localhost port 8080"
   )
-
 })
 
 test_that("otp_geocode input validation", {
